@@ -23,6 +23,10 @@ class GenerateHandler(BaseHandler):
     def get(self):
         in_text = self.get_argument('q')
         in_mode = to_alpha3_code(self.get_argument('lang'))
+        if '-' in in_mode:
+            l1, l2 = map(to_alpha3_code, in_mode.split('-', 1))
+            in_mode = '%s-%s' % (l1, l2)
+        in_mode = self.find_fallback_mode(in_mode, self.generators)
         if in_mode in self.generators:
             [path, mode] = self.generators[in_mode]
             formatting = 'none'
